@@ -2,14 +2,9 @@
 #'
 #' Add a scalebar to default or (UTM)-projected OpenStreetMap plots
 #'
-#' @details This uses a hack to get the right distance in the default mercator projected maps.
+#' @details scaleBar gets the right distance in the default mercator projected maps.
 #' There, the axes are not in meters, but rather ca 0.7m units (for NW Germany area maps with 20km across).
-#' Accordingly, other packages plot wrong bars:\cr
-#' SDMTools::Scalebar(x=1442638,y=6893871,distance=10000)\cr
-#' raster::scalebar(d=5000, xy=c(1442638,6893871))\cr
-#' mapmisc::scaleBar(map$tiles[[1]]$projection, seg.len=10, pos="center", bg="transparent")\cr
-#' I suppose this function works for other projections as well, but haven't tried yet.
-#' You might need to specify abslen manually with other projections where the axes do not resemble meters at all.
+#' Accordingly, other packages plot wrong bars, see the last example section.
 #'
 #' @return invisible: coordinates of scalebar and label
 #' @author Berry Boessenkool, \email{berry-b@@gmx.de}, Jun 2016
@@ -43,21 +38,28 @@
 #' map2 <- pointsMap(lat, long, map=map, utm=TRUE)
 #' }
 #'
+#' \dontrun{ ## excluded from tests to avoid package dependencies
+#' install.packages(c("OSMscale","SDMTools","raster","mapmisc"))
+#' par(mar=c(0,0,0,0))
+#' map <- OSMscale::pointsMap(long=c(12.95, 13.22), lat=c(52.52, 52.36))
+#' SDMTools::Scalebar(x=1443391,y=6889679,distance=10000)
+#' raster::scalebar(d=10000, xy=c(1443391,6884254))
+#' OSMscale::scaleBar(map, x=0.35, y=0.45, abslen=5)
+#' library(mapmisc) # otherwise rbind for SpatialPoints is not found
+#' mapmisc::scaleBar(map$tiles[[1]]$projection, seg.len=10, pos="center", bg="transparent")
+#' }
+#'
 #' @param map Map object with map$tiles[[1]]$projection to get the projection from.
 #' @param x,y Relative position of left end of scalebar. DEFAULT: 0.1, 0.9
 #' @param length Approximate relative length of bar. DEFAULT: 0.4
 #' @param abslen Absolute length in \code{unit}s. DEFAULT: NA (computed internally from \code{length})
 #' @param unit Unit for computation and label.
-#'             Possible are kilometer and meter as well as miles, feet and yards.
-#'             Note that the returned absolute length is in m. DEFAULT: "km"
+#'             Possible: kilometer, meter, miles, feet, yards. DEFAULT: "km"
 #' @param label Unit label in plot. DEFAULT: \code{unit}
 #' @param type Scalebar type: simple \code{'line'} or classical black & white \code{'bar'}. DEFAULT: "bar"
 #' @param ndiv Number of divisions if \code{type="bar"}. DEFAULT: NA (computed internally)
 #'             Internal selection of \code{ndiv} is based on divisibility of abslen
 #'             (modulo) with 1:6. For ties, preferation order is 5>4>3>2>6>1.
-#'             For maps with abslen=4000, this means 5 will be chosen,
-#'             even though 4 is more appealing. if \code{abslen} is also missing
-#'             (or in a certain set), a better default is chosen.
 #' @param field,fill,adj,cex Arguments passed to \code{\link[berryFunctions]{textField}}
 #' @param col Vector of (possibly alternating) colors passed to
 #'            \code{\link{segments}} or \code{\link{rect}}. DEFAULT: c("black","white")
@@ -128,8 +130,9 @@ y <- r[3]+y*diff(r[3:4])
 # choice of length and ndiv possibilities for default automatic selection
 xy_ll <- projectPoints(rep(y,2), c(x1,x2), to=pll(), from=crs)
 xy_d <- earthDist(xy_ll$y, xy_ll$x, trace=FALSE)*1000/f # in units
-cl <- c( 1,2,3,4,5,6,8,  c(10,15,20,25,30,40,50,60,80,100)*10^(floor(log10(xy_d))-1)  )
-cn <- c( 1,2,3,4,5,6,4,     5, 3, 4, 5, 6, 4, 5, 3, 4,  5)
+xy_d <- xy_d[2]
+cl <- c( 1,2,3,4,5,  c(10,15,20,25,30,40,50,100)*10^(floor(log10(xy_d))-1)  )
+cn <- c( 5,4,3,4,5,     5, 3, 4, 5, 6, 4, 5,  5)
 if(is.na(abslen))
   {
   csel <- which.min(abs(xy_d-cl)) # which/match is important to select first occurence
@@ -197,5 +200,7 @@ if(type=="bar")
 stop("type ", type, " is not implemented. Please use 'bar' or 'line'.")
 #
 # return absolute coordinates
-return(invisible(c(x1=x1, x2=x2, y=y, abslen=abslen, label=xl))) # , unit=unit
+sb <- c(x1=x1, x2=x2, y=y, abslen=abslen, unit=f, ndiv=ndiv, label=xl)
+names(sb)[5] <- paste("unit", unit, sep=":")
+return(invisible(sb))
 }
